Page 175 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 175

Home

    individual must be sacrificed if necessary, for, and this is
    the phrase that you have heard so many times, "for the
    greater good of the greater number." Basically, the
    collectivist believes that the individual is not responsible
    for his own welfare, that it is the responsibility of the
    group to take care of him. That means, of course, the
    State.

    individual is the most important element in society, and
    that any doctrine which ignores the individual's rights is
    a false doctrine. The individualist also believes in doing

    ae c 1 wos a . wad

    things for himself, in having as little government as
    possible, so that the individual is responsible for himself,
    his family and his loved ones.

    re a 4 1 cle

    If we were just facing the philosophy of Marxism,
    then we could easily defeat it with the philosophy of
    freedom. If we were just fighting against the concept of
    Collectivism, we could easily defeat it with the superior
    ideology of Individualism. But that's not what we are
    facing. We're facing the combination of ideology and
    organization. We're facing a well-disciplined literally
    worldwide army of people who have leaders, follow
    directions, take orders, and work in unison to accomplish
    targeted goals. The only way that ° we who want to

    tae

    preserve our freedom can oppose that, and defeat it, is
    not only with just a superior ideology of individualism,
    but we must also have a superior, or at least an equally
    efficient organization to oppose their organization.*

    This understanding of the basic nature of the struggle
    between Collectivism and Individualism easily enabled
    members of the JBS to identify the enemies of freedom.
    These enemies always work for more government, less

    170

    The Secret Side of History

    The individualist, on the other hand, believes that the